boiler
======

::
A command line tool to quick manage boilerplate structures called **plates**, it is extensible

example usage::

	$ boiler -l 

	Present plates

	=================================================================================================================
	| plate name           | type       | author     | description                                                  |
	=================================================================================================================
	| initscript           | copy       | mogui      | A template for init.d script of non-daemon app               |
	| wordpress            | bash       | mogui      | A quick way to have the latest wordpress version             |
	| wp_theme             | bash       | mogui      | Wordpress theme bare template                                |
	=================================================================================================================
	

    $ boiler initscript nameyouwant_forscript

The basic idea is to have a central way to recall common script template or frequently used folder layout and the likes.    
It is all based on tpl files / folder called **plates** which are the template to create.

- `boiler -l` will list all available plates to fire
- `boiler <plate_name> help` will give help on that plate
- `boiler <plate_name> [new_name]` will create the boilerplate in current directory with new_name name

Install
-------

**from Package index**::

	$ pip install boiler

**From source**

download or clone from here, then::

	$ python setup.py install

Write Custom Tpl
----------------

Refer to `Tpl repository <https://github.com/mogui/boiler_templates>`_

Copyright
---------

Copyright © 2012 Niko Usai. See LICENSE for details.



